This code was originally published by the following individuals for use with Scilab:

* Copyright (C) 2012 - 2013 - **Michael Baudin**
* Copyright (C) 2012 - **Maria Christopoulou**
* Copyright (C) 2010 - 2011 - INRIA - **Michael Baudin**
* Copyright (C) 2009 - **Yann Collette**
* Copyright (C) 2009 - CEA - **Jean-Marc Martinez**

## pyDOE

Copyright (c) 2014, **Abraham D. Lee** & **tisimst**

## pyDOE2

Copyright (c) 2018, **Rickard Sjögren** & **Daniel Svensson**
**Much thanks goes to these awesome individuals, contributors, maintainers.**
